@@ -33,10 +33,17 @@ public class ProtocolTest {
     }
 
     @Test public void canLookupIpProtocolByName() {
+        // we try ip first and then ipv4 due to jnr/jnr-netdb#4
         Protocol p = Protocol.getProtocolByName("ip");
-        assertNotNull("could not lookup ip protocol", p);
-        assertEquals("incorrect proto number", 0, p.getProto());
-        assertEquals("incorrect name", "ip", p.getName());
+        if (p != null) {
+            assertEquals("incorrect proto number", 0, p.getProto());
+            assertEquals("incorrect name", "ip", p.getName());
+        } else {
+            p = Protocol.getProtocolByName("ipv4");
+            assertNotNull("could not lookup ipv4 protocol", p);
+            assertEquals("incorrect proto number", 4, p.getProto());
+            assertEquals("incorrect name", "ipv4", p.getName());
+        }
     }
 
     @Test public void returnsNullOnUnknownProtocol() {
@@ -45,10 +52,18 @@ public class ProtocolTest {
     }
 
     @Test public void canLookupIpProtocolByNumber() {
-        Protocol p = Protocol.getProtocolByNumber(0);
-        assertNotNull("could not lookup ip protocol", p);
-        assertEquals("incorrect proto number", 0, p.getProto());
-        assertEquals("incorrect name", "ip", p.getName());
+        // we try ip first and then ipv4 due to jnr/jnr-netdb#4
+        Protocol p = Protocol.getProtocolByName("ip");
+        if (p != null) {
+            p = Protocol.getProtocolByNumber(0);
+            assertEquals("incorrect proto number", 0, p.getProto());
+            assertEquals("incorrect name", "ip", p.getName());
+        } else {
+            p = Protocol.getProtocolByNumber(4);
+            assertNotNull("could not lookup ip protocol", p);
+            assertEquals("incorrect proto number", 4, p.getProto());
+            assertEquals("incorrect name", "ipv4", p.getName());
+        }
     }
 
     @Test public void returnsNullOnInvalidNumber() {
